package github.benjamin.equipreservebackend.controller;

import github.benjamin.equipreservebackend.dto.TeamDTO;
import github.benjamin.equipreservebackend.response.ResponseResult;
import github.benjamin.equipreservebackend.service.TeamService;
import github.benjamin.equipreservebackend.vo.TeamLabelVO;
import github.benjamin.equipreservebackend.vo.TeamVO;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping
@RequiredArgsConstructor
public class TeamController {

    private final TeamService teamService;

    @GetMapping("/team-label")
    public ResponseResult<List<TeamLabelVO>> getTeamLabel() {
        return ResponseResult.success(teamService.getTeamLabel());
    }

    @GetMapping("/teams")
    public ResponseResult<List<TeamVO>> getTeams() {
        return ResponseResult.success(teamService.getTeams());
    }

    @PreAuthorize("hasRole('ADMIN')")
    @DeleteMapping("/team/{id}")
    public ResponseResult<?> deleteTeam(@PathVariable("id") Long id) {
        teamService.deleteTeam(id);
        return ResponseResult.success();
    }

    @PreAuthorize("hasRole('ADMIN')")
    @PostMapping("/team")
    public ResponseResult<?> addTeam(@RequestBody TeamDTO dto) {
        teamService.addTeam(dto.getName());
        return ResponseResult.success();
    }

    @PreAuthorize("hasRole('ADMIN')")
    @PutMapping("/team/{id}")
    public ResponseResult<?> updateTeam(@PathVariable Long id,
                                        @RequestBody TeamDTO dto) {
        teamService.updateTeam(id, dto.getName());
        return ResponseResult.success();
    }
}
